@@ -1,5 +1,9 @@
+from datetime import datetime, date
 from enum import Enum, IntEnum
-from typing import TYPE_CHECKING, Optional, Sequence, Union
+from typing import Optional, Sequence, Union
+
+from pydantic import BaseModel
+
 
 try:
     from typing import Literal
@@ -12,15 +16,6 @@ CalcbenchCompanyIdentifier = int
 CompanyIdentifier = Union[Ticker, CentralIndexKey, CalcbenchCompanyIdentifier]
 CompanyIdentifiers = Sequence[CompanyIdentifier]
 
-if TYPE_CHECKING:
-    # https://github.com/microsoft/pyright/issues/1358
-    from typing import TypedDict
-else:
-    try:
-        from typing import TypedDict
-    except ImportError:
-        from typing_extensions import TypedDict
-
 
 class CompanyIdentifierScheme(str, Enum):
     Ticker = "ticker"
@@ -54,18 +49,35 @@ class Period(IntEnum):
 PeriodArgument = Optional[Union[Period, Literal[0, 1, 2, 3, 4]]]
 
 
-class CompaniesParameters(TypedDict):
-    companyIdentifiers: CompanyIdentifiers
-    entireUniverse: bool
+class CompaniesParameters(BaseModel):
+    companyIdentifiers: Optional[CompanyIdentifiers]
+    entireUniverse: Optional[bool]
 
 
-class PeriodParameters(TypedDict, total=False):
-    year: Optional[int]
-    period: Optional[Period]
-    periodType: Optional[PeriodType]
+class DateRange(BaseModel):
+    startDate: Optional[Union[datetime, date]]
+    endDate: Optional[Union[datetime, date]]
 
 
-class APIQueryParams(TypedDict):
+class PeriodParameters(BaseModel):
+    """
+    Corresponds to PeriodParameter.cs
+    """
+
+    year: Optional[int] = None
+    period: Optional[PeriodArgument] = None
+    periodType: Optional[PeriodType] = None
+    dateRange: Optional[DateRange] = None
+    endYear: Optional[int] = None
+    endPeriod: Optional[PeriodArgument] = None
+    allHistory: Optional[bool] = None
+    updateDate: Optional[date] = None
+    useFiscalPeriod: Optional[bool] = None
+    accessionID: Optional[int] = None
+    filingID: Optional[int] = None
+
+
+class APIQueryParams(BaseModel):
     companiesParameters: Optional[CompaniesParameters]
     periodParameters: Optional[PeriodParameters]
     pageParameters: Optional[object]
